/*
     * jQuery accessible simple (non-modal) tooltip window, using ARIA
     * @version v2.2.0
     * Website: https://a11y.nicolas-hoffmann.net/simple-tooltip/
     * License MIT: https://github.com/nico3333fr/jquery-accessible-simple-tooltip-aria/blob/master/LICENSE
     */

(function(factory) {
  'use strict';
  if (typeof define === 'function' && define.amd) {
      define(['jquery'], factory);
  } else if (typeof exports !== 'undefined') {
      module.exports = factory(require('jquery'));
  } else {
      factory(window.jQuery);
  }
}(function($) {
  function accessibleSimpleTooltipAria(options) {
    var element = $(this);
    options = options || element.data();
    var text = options.simpletooltipText || '';
    var prefix_class = typeof options.simpletooltipPrefixClass !== 'undefined' ? options.simpletooltipPrefixClass + '-' : '';
    var content_id = typeof options.simpletooltipContentId !== 'undefined' ? '#' + options.simpletooltipContentId : '';

    var index_lisible = Math.random().toString(32).slice(2, 12);
    var aria_describedby = element.attr('aria-describedby') || '';

    element.attr({
        'aria-describedby': 'label_simpletooltip_' + index_lisible + ' ' + aria_describedby
    });

    var parent = element.closest('ul');

    var html = '<span class="' + prefix_class + 'simpletooltip" id="label_simpletooltip_' + index_lisible + '" role="tooltip" aria-hidden="true">';

    if (text !== '') {
        html += '' + text + '';
    } else {
        var $contentId = $(content_id);
        if (content_id !== '' && $contentId.length) {
            html += $contentId.html();
        }
    }
    html += '</span>';

    parent.before($(html));
  }

    // Bind as a jQuery plugin
  $.fn.accessibleSimpleTooltipAria = accessibleSimpleTooltipAria;

  $.fn.extend({
    toggleToolTip: function(hidden) {
      var aria_describedby = this.attr('aria-describedby');
      var tooltip_to_show_id = aria_describedby.substr(0, aria_describedby.indexOf(" "));
      var $tooltip_to_show = $('#' + tooltip_to_show_id);
      $tooltip_to_show.attr('aria-hidden', hidden);
    }
  });

  $(document).ready(function() {

    $('.js-simple-tooltip')
      .each(function() {
        // Call the function with this as the current tooltip
        accessibleSimpleTooltipAria.apply(this);
      });

    // events ------------------
    $('body').on('focusin', '.js-simple-tooltip', function() {
      $(this).keyup(function(e) {
        $(this).toggleToolTip('false');
      });
    }).on('focusout', '.js-simple-tooltip', function() {
      $(this).toggleToolTip('true');
    });
  });
}));
